photoshare (1)
==================

NAME
----

photoshare - Manage a list of which photos (or other files) you've shared,
using metapho's tagging system and the special tag 'share'.

SYNOPSIS
--------

photoshare  
Search in the current directory (or directories specified with -d)
for images that have not been shared.

photoshare img2.jpg img.jpg ...  
Check whether the specified images have been shared, and when

photoshare add img2.jpg img.jpg ...  
Add the specified images to the share list with today's date


OPTIONAL FLAGS
--------------

-----
|   |   |
|---|---|
| -h, --help  | show this help message and exit |
| -d DIRLIST  | Directories to search, comma-separated |



AUTHOR
------

Akkana Peck.

COPYRIGHT
---------

Copyright (C) 2024 Akkana Peck.
Part of Metapho, which is free software,
licensed under the GNU Public License version 2 (or later).

SEE ALSO
--------

The most recent version of `metapho`, and more information about it, is at:
https://github.com/akkana/metapho
